/*
  Copyright 2020 Kakao Corp.

  Licensed under the Apache License, Version 2.0 (the "License");
  you may not use this file except in compliance with the License.
  You may obtain a copy of the License at

     http://www.apache.org/licenses/LICENSE-2.0

  Unless required by applicable law or agreed to in writing, software
  distributed under the License is distributed on an "AS IS" BASIS,
  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
  See the License for the specific language governing permissions and
  limitations under the License.
 */
package com.kakao.sdk.partner.auth


import android.content.Context
import com.kakao.sdk.auth.AuthApiClient
import com.kakao.sdk.auth.AuthApiManager
import com.kakao.sdk.auth.model.OAuthToken
import com.kakao.sdk.auth.network.kauth
import com.kakao.sdk.network.ApiFactory
import com.kakao.sdk.partner.auth.model.*

/**
 * 그룹 내 다른 앱의 refreshToken으로 사용자를 인증하여 현재 앱의 토큰을 발급 받습니다.
 *
 * 이 기능을 사용하더라도 사용자 인증에 사용하는 refreshToken 값을 앱 사이에 공유하지 않으며, 현재 앱을 위한 새로운 [OAuthToken] 세트가 발급됩니다.
 *
 * @param groupRefreshToken 사용자 인증에 사용할 그룹 내 다른 앱의 refreshToken.
 * @param callback 발급 받은 [OAuthToken] 반환.
 */
fun AuthApiClient.issueAccessToken(
    groupRefreshToken: String,
    callback: (token: OAuthToken?, error: Throwable?) -> Unit
) = AuthApiManager.instance.issueAccessToken(groupRefreshToken, callback)

/**
 * 연령 인증 요청
 *
 *
 * @param context    CustomTabs를 실행하기 위한 현재 Activity context
 * @param ageLimit   연령제한 (만 나이 기준)
 * @param authLevel  연령인증 레벨 (1차 인증 : 실명/생년월일 인증, 2차 인증 : 휴대폰 본인 인증을 통한 통신사 명의자 인증)
 * @param skipTerms  동의 화면 출력 여부
 * @param adultsOnly 서비스에서 청소년유해매채물 인증 필요 여부
 * @param underAge   연령인증 페이지 구분
 * @param callback   연령인증 결과 받음 (error 가 null 일 경우 연령인증 성공)
 *
 */
fun AuthApiClient.verifyAge(
    context: Context,
    ageLimit : Int? = null,
    authLevel : AgeAuthLevel? = null,
    skipTerms : Boolean? = null,
    adultsOnly : Boolean? = null,
    underAge : Boolean? = false,
    callback: (error: Throwable?) -> Unit) =
    AgeAuthManager.instance.verifyAgeWithAuthentication(context, ageLimit, authLevel, skipTerms, adultsOnly, underAge, callback)


